take_it_easy
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

The game has two modes:

“play”: In the play mode, the entire game will be simulated including
drawing tiles randomly. This is usefull to play with the computer or to
train an Reinforcement Learning algorithm

“input”: In input mode, the user specifies what tile has been drawn,
e.g., when playing a real-life game

## Install

``` sh
pip install take_it_easy
```

## How to use

To play the game with random actions:

``` python
from take_it_easy.tiles import Tiles
from take_it_easy.board import Board
from take_it_easy.play import play_random_game
```

``` python
board = Board()
tiles = Tiles()
play_random_game(board, tiles)
```

    Score impact: 0, potential score impact: 19
    Score impact: 0, potential score impact: 15
    Score impact: 0, potential score impact: 10
    Score impact: 0, potential score impact: -1
    Score impact: 0, potential score impact: 11
    Score impact: 0, potential score impact: 4
    Score impact: 0, potential score impact: 13
    Score impact: 0, potential score impact: -12
    Score impact: 0, potential score impact: 7
    Score impact: 0, potential score impact: 1
    Score impact: 0, potential score impact: 6
    Score impact: 0, potential score impact: -2
    Score impact: 0, potential score impact: -14
    Score impact: 0, potential score impact: -6
    Score impact: 0, potential score impact: -15
    Score impact: 0, potential score impact: -12
    Score impact: 0, potential score impact: -24
    Score impact: 0, potential score impact: 0
    Score impact: 0, potential score impact: 0
    finished game with score:  0
